Documentation
¶
Overview ¶
Copyright 2025 The canary-gate authors
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Copyright 2025 The canary-gate authors ¶
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Copyright 2025 The canary-gate authors ¶
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Index ¶
- type Client
- type QuietNoti
- func (w QuietNoti) AddFileToThreads(slackMessages map[string]string, fileName string, content string) error
- func (w QuietNoti) SendMessages(text string, hookType service.HookType, meta map[string]string) (map[string]string, error)
- func (w QuietNoti) UpdateMessages(slackMessages map[string]string, text string, context string) error
- type SlackOption
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
type Client interface {
SendMessages(text string, hookType service.HookType, meta map[string]string) (map[string]string, error)
UpdateMessages(slackMessages map[string]string, text, context string) error
AddFileToThreads(slackMessages map[string]string, fileName, content string) error
}
func NewQuietNoti ¶
func NewQuietNoti() Client
func NewSlackClient ¶
func NewSlackClient(option SlackOption) Client
type QuietNoti ¶
type QuietNoti struct {
}
func (QuietNoti) AddFileToThreads ¶
func (w QuietNoti) AddFileToThreads(slackMessages map[string]string, fileName string, content string) error
AddFileToThreads implements Client.